@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -121,7 +121,7 @@ public class SyndMessage implements MessagingMessage {
     }
 
     private String createId(final String link, final String title, final Date publishedDate) {
-        final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator();
+        final StringBuilder sb = new StringBuilder();
         if (link != null) {
             sb.append(link);
         }
