@@ -23,14 +23,7 @@ import twitter4j.auth.AccessToken;
 import twitter4j.auth.RequestToken;
 
 import java.awt.*;
-import java.io.BufferedReader;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.InputStreamReader;
-import java.io.OutputStream;
+import java.io.*;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.util.Properties;
@@ -73,13 +66,13 @@ public class GetAccessToken {
             ioe.printStackTrace();
             System.exit(-1);
         } finally {
-            if (null != is) {
+            if (is != null) {
                 try {
                     is.close();
                 } catch (IOException ignore) {
                 }
             }
-            if (null != os) {
+            if (os != null) {
                 try {
                     os.close();
                 } catch (IOException ignore) {
@@ -100,6 +93,7 @@ public class GetAccessToken {
                 System.out.println(requestToken.getAuthorizationURL());
                 try {
                     Desktop.getDesktop().browse(new URI(requestToken.getAuthorizationURL()));
+                } catch (UnsupportedOperationException ignore) {
                 } catch (IOException ignore) {
                 } catch (URISyntaxException e) {
                     throw new AssertionError(e);
@@ -134,7 +128,7 @@ public class GetAccessToken {
                 ioe.printStackTrace();
                 System.exit(-1);
             } finally {
-                if (null != os) {
+                if (os != null) {
                     try {
                         os.close();
                     } catch (IOException ignore) {
